@@ -36,10 +36,8 @@ class CfnMicrosoftAD(
 ):
     """A CloudFormation ``AWS::DirectoryService::MicrosoftAD``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DirectoryService::MicrosoftAD
+    :cloudformationResource: AWS::DirectoryService::MicrosoftAD
     """
 
     def __init__(
@@ -49,7 +47,7 @@ class CfnMicrosoftAD(
         *,
         name: builtins.str,
         password: builtins.str,
-        vpc_settings: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable],
+        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         edition: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
@@ -81,11 +79,10 @@ class CfnMicrosoftAD(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -110,8 +107,7 @@ class CfnMicrosoftAD(
     @jsii.member(jsii_name="attrAlias")
     def attr_alias(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Alias
+        :cloudformationAttribute: Alias
         """
         return jsii.get(self, "attrAlias")
 
@@ -119,8 +115,7 @@ class CfnMicrosoftAD(
     @jsii.member(jsii_name="attrDnsIpAddresses")
     def attr_dns_ip_addresses(self) -> typing.List[builtins.str]:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: DnsIpAddresses
+        :cloudformationAttribute: DnsIpAddresses
         """
         return jsii.get(self, "attrDnsIpAddresses")
 
@@ -134,7 +129,6 @@ class CfnMicrosoftAD(
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
         """
         return jsii.get(self, "name")
@@ -148,7 +142,6 @@ class CfnMicrosoftAD(
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
         """
         return jsii.get(self, "password")
@@ -161,10 +154,9 @@ class CfnMicrosoftAD(
     @jsii.member(jsii_name="vpcSettings")
     def vpc_settings(
         self,
-    ) -> typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]:
+    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
         """
         return jsii.get(self, "vpcSettings")
@@ -172,7 +164,7 @@ class CfnMicrosoftAD(
     @vpc_settings.setter # type: ignore
     def vpc_settings(
         self,
-        value: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable],
+        value: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
     ) -> None:
         jsii.set(self, "vpcSettings", value)
 
@@ -183,7 +175,6 @@ class CfnMicrosoftAD(
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-createalias
         """
         return jsii.get(self, "createAlias")
@@ -200,7 +191,6 @@ class CfnMicrosoftAD(
     def edition(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.Edition``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-edition
         """
         return jsii.get(self, "edition")
@@ -216,7 +206,6 @@ class CfnMicrosoftAD(
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-enablesso
         """
         return jsii.get(self, "enableSso")
@@ -233,7 +222,6 @@ class CfnMicrosoftAD(
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-shortname
         """
         return jsii.get(self, "shortName")
@@ -258,7 +246,6 @@ class CfnMicrosoftAD(
             :param subnet_ids: ``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
             :param vpc_id: ``CfnMicrosoftAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -270,7 +257,6 @@ class CfnMicrosoftAD(
         def subnet_ids(self) -> typing.List[builtins.str]:
             """``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-subnetids
             """
             result = self._values.get("subnet_ids")
@@ -281,7 +267,6 @@ class CfnMicrosoftAD(
         def vpc_id(self) -> builtins.str:
             """``CfnMicrosoftAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-vpcid
             """
             result = self._values.get("vpc_id")
@@ -319,7 +304,7 @@ class CfnMicrosoftADProps:
         *,
         name: builtins.str,
         password: builtins.str,
-        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable],
+        vpc_settings: typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         edition: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
@@ -335,7 +320,6 @@ class CfnMicrosoftADProps:
         :param enable_sso: ``AWS::DirectoryService::MicrosoftAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -356,7 +340,6 @@ class CfnMicrosoftADProps:
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
         """
         result = self._values.get("name")
@@ -367,7 +350,6 @@ class CfnMicrosoftADProps:
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::MicrosoftAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
         """
         result = self._values.get("password")
@@ -377,10 +359,9 @@ class CfnMicrosoftADProps:
     @builtins.property
     def vpc_settings(
         self,
-    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable]:
+    ) -> typing.Union[CfnMicrosoftAD.VpcSettingsProperty, aws_cdk.core.IResolvable]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
         """
         result = self._values.get("vpc_settings")
@@ -393,7 +374,6 @@ class CfnMicrosoftADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-createalias
         """
         result = self._values.get("create_alias")
@@ -403,7 +383,6 @@ class CfnMicrosoftADProps:
     def edition(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.Edition``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-edition
         """
         result = self._values.get("edition")
@@ -415,7 +394,6 @@ class CfnMicrosoftADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-enablesso
         """
         result = self._values.get("enable_sso")
@@ -425,7 +403,6 @@ class CfnMicrosoftADProps:
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::MicrosoftAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-shortname
         """
         result = self._values.get("short_name")
@@ -451,10 +428,8 @@ class CfnSimpleAD(
 ):
     """A CloudFormation ``AWS::DirectoryService::SimpleAD``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DirectoryService::SimpleAD
+    :cloudformationResource: AWS::DirectoryService::SimpleAD
     """
 
     def __init__(
@@ -465,7 +440,7 @@ class CfnSimpleAD(
         name: builtins.str,
         password: builtins.str,
         size: builtins.str,
-        vpc_settings: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"],
+        vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
@@ -499,11 +474,10 @@ class CfnSimpleAD(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -528,8 +502,7 @@ class CfnSimpleAD(
     @jsii.member(jsii_name="attrAlias")
     def attr_alias(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Alias
+        :cloudformationAttribute: Alias
         """
         return jsii.get(self, "attrAlias")
 
@@ -537,8 +510,7 @@ class CfnSimpleAD(
     @jsii.member(jsii_name="attrDnsIpAddresses")
     def attr_dns_ip_addresses(self) -> typing.List[builtins.str]:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: DnsIpAddresses
+        :cloudformationAttribute: DnsIpAddresses
         """
         return jsii.get(self, "attrDnsIpAddresses")
 
@@ -552,7 +524,6 @@ class CfnSimpleAD(
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
         """
         return jsii.get(self, "name")
@@ -566,7 +537,6 @@ class CfnSimpleAD(
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
         """
         return jsii.get(self, "password")
@@ -580,7 +550,6 @@ class CfnSimpleAD(
     def size(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Size``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
         """
         return jsii.get(self, "size")
@@ -593,10 +562,9 @@ class CfnSimpleAD(
     @jsii.member(jsii_name="vpcSettings")
     def vpc_settings(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
         """
         return jsii.get(self, "vpcSettings")
@@ -604,7 +572,7 @@ class CfnSimpleAD(
     @vpc_settings.setter # type: ignore
     def vpc_settings(
         self,
-        value: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"],
+        value: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
     ) -> None:
         jsii.set(self, "vpcSettings", value)
 
@@ -615,7 +583,6 @@ class CfnSimpleAD(
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-createalias
         """
         return jsii.get(self, "createAlias")
@@ -632,7 +599,6 @@ class CfnSimpleAD(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-description
         """
         return jsii.get(self, "description")
@@ -648,7 +614,6 @@ class CfnSimpleAD(
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-enablesso
         """
         return jsii.get(self, "enableSso")
@@ -665,7 +630,6 @@ class CfnSimpleAD(
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-shortname
         """
         return jsii.get(self, "shortName")
@@ -690,7 +654,6 @@ class CfnSimpleAD(
             :param subnet_ids: ``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
             :param vpc_id: ``CfnSimpleAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html
             """
             self._values: typing.Dict[str, typing.Any] = {
@@ -702,7 +665,6 @@ class CfnSimpleAD(
         def subnet_ids(self) -> typing.List[builtins.str]:
             """``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-subnetids
             """
             result = self._values.get("subnet_ids")
@@ -713,7 +675,6 @@ class CfnSimpleAD(
         def vpc_id(self) -> builtins.str:
             """``CfnSimpleAD.VpcSettingsProperty.VpcId``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-vpcid
             """
             result = self._values.get("vpc_id")
@@ -753,7 +714,7 @@ class CfnSimpleADProps:
         name: builtins.str,
         password: builtins.str,
         size: builtins.str,
-        vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"],
+        vpc_settings: typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty],
         create_alias: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
         enable_sso: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
@@ -770,7 +731,6 @@ class CfnSimpleADProps:
         :param enable_sso: ``AWS::DirectoryService::SimpleAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::SimpleAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -792,7 +752,6 @@ class CfnSimpleADProps:
     def name(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Name``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
         """
         result = self._values.get("name")
@@ -803,7 +762,6 @@ class CfnSimpleADProps:
     def password(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Password``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
         """
         result = self._values.get("password")
@@ -814,7 +772,6 @@ class CfnSimpleADProps:
     def size(self) -> builtins.str:
         """``AWS::DirectoryService::SimpleAD.Size``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
         """
         result = self._values.get("size")
@@ -824,10 +781,9 @@ class CfnSimpleADProps:
     @builtins.property
     def vpc_settings(
         self,
-    ) -> typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, CfnSimpleAD.VpcSettingsProperty]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
         """
         result = self._values.get("vpc_settings")
@@ -840,7 +796,6 @@ class CfnSimpleADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-createalias
         """
         result = self._values.get("create_alias")
@@ -850,7 +805,6 @@ class CfnSimpleADProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-description
         """
         result = self._values.get("description")
@@ -862,7 +816,6 @@ class CfnSimpleADProps:
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-enablesso
         """
         result = self._values.get("enable_sso")
@@ -872,7 +825,6 @@ class CfnSimpleADProps:
     def short_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DirectoryService::SimpleAD.ShortName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-shortname
         """
         result = self._values.get("short_name")
